@@ -16,6 +16,9 @@
 #'   is the label assigned to the level in the data dictionary. This option 
 #'   is only available after REDCap version 6.0.
 #' @param bundle A \code{redcapBundle} object as created by \code{exportBundle}.
+#' @param drop An optional character vector of REDCap variable names to remove from the 
+#'   dataset; defaults to NULL. E.g., \code{drop=c("date_dmy", "treatment")} 
+#'   It is OK for drop to contain variables not present; these names are ignored.
 #' @param ... Additional arguments to be passed between methods.
 #' @param error_handling An option for how to handle errors returned by the API.
 #'   see \code{\link{redcap_error}}
@@ -49,24 +52,28 @@
 #' 
 #' @export
 
-exportReports <- function(rcon, report_id, factors=TRUE, labels=TRUE, 
-                          dates=TRUE, checkboxLabels=FALSE, ...)
+exportReports <- function(rcon, 
+                          report_id, 
+                          factors = TRUE, 
+                          labels = TRUE, 
+                          dates = TRUE, 
+                          drop = NULL,
+                          checkboxLabels = FALSE, 
+                          ...){
   UseMethod("exportReports")
-
-#' @rdname exportReports
-#' @export
-
-exportReports.redcapDbConnection <- function(rcon, report_id, factors=TRUE, labels=TRUE, 
-                                             dates=TRUE, checkboxLabels=FALSE, ...){
-  message("Please accept my apologies.  The exportMappings method for redcapDbConnection objects\n",
-          "has not yet been written.  Please consider using the API.")          
 }
 
 #' @rdname exportReports
 #' @export
 
-exportReports.redcapApiConnection <- function(rcon, report_id, factors = TRUE, labels = TRUE, 
-                                              dates = TRUE, checkboxLabels = FALSE, ...,
+exportReports.redcapApiConnection <- function(rcon, 
+                                              report_id, 
+                                              factors = TRUE, 
+                                              labels = TRUE, 
+                                              dates = TRUE, 
+                                              drop = NULL, 
+                                              checkboxLabels = FALSE, 
+                                              ...,
                                               bundle = getOption("redcap_bundle"),
                                               error_handling = getOption("redcap_error_handling")){
   
@@ -104,23 +111,15 @@ exportReports.redcapApiConnection <- function(rcon, report_id, factors = TRUE, l
   checkmate::reportAssertions(coll)
   
   #* Secure the meta data.
-  meta_data <- 
-    if (is.null(bundle$meta_data)) 
-      exportMetaData(rcon) 
-  else 
-    bundle$meta_data
-  
+  meta_data <- rcon$metadata()
+
   #* for purposes of the export, we don't need the descriptive fields. 
   #* Including them makes the process more error prone, so we'll ignore them.
   meta_data <- meta_data[!meta_data$field_type %in% "descriptive", ]  
   
   #* Secure the REDCap version
-  version <- 
-    if (is.null(bundle$version))
-      exportVersion(rcon)
-  else
-    bundle$version
-  
+  version <- rcon$version()
+
   body <- list(token = rcon$token, 
                content = 'report',
                format = 'csv', 
@@ -147,6 +146,7 @@ exportReports.redcapApiConnection <- function(rcon, report_id, factors = TRUE, l
                   meta_data = meta_data, 
                   factors = factors, 
                   dates = dates, 
+                  labels=labels,
                   checkboxLabels = checkboxLabels,
                   ...)
   
@@ -164,8 +164,7 @@ exportReports.redcapApiConnection <- function(rcon, report_id, factors = TRUE, l
     field_names <- field_names[field_names %in% meta_data$field_name]
 
     suffixed <- checkbox_suffixes(fields = field_names,
-                                  meta_data = meta_data, 
-                                  version = version)
+                                  meta_data = meta_data)
 
     x[suffixed$name_suffix] <-
       mapply(nm = suffixed$name_suffix,
@@ -180,6 +179,11 @@ exportReports.redcapApiConnection <- function(rcon, report_id, factors = TRUE, l
              SIMPLIFY = FALSE)
   }
   
+  # drop
+  if(length(drop)) {
+    x <- x[!names(x) %in% drop]
+  } # end drop
+  
   x 
   
 }
\ No newline at end of file
